.. _report:

Reports
=======

This chapter explains how to generate reports in TCMS.

Reports by Product and Version
------------------------------

TCMS can generate a list of Test Plans, Cases and Runs by product,
version, component, and build.

Procedure: View a product report
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

To view a product report:

#. Click the **REPORTING** tab.

   |The Reporting button 1|

#. Click the **Product Name**.

   |The product selection screen.|

   The product overview is displayed.

   |The product overview screen.|

#. Click **Versions** to view the report sorted on product version.

   |The product version screen.|

#. Click **Builds** to view the report sorted on product builds.

   |The product build screen.|

#. Click **Components** to view the report sorted on product components.

Custom Reports
--------------

TCMS can generate a custom report based on search conditions.

Procedure: Create a custom report
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

To create a product report:

#. From the **REPORTING** tab, click **Custom**

   |The Reporting button 2|

#. Enter the search details:

   -  Product
   -  Product version
   -  Case category
   -  Case component
   -  Plan name
   -  Build

   |Search details. 1|

#. Click **Search**. The results are displayed.

   |Report Results.|

Testing Reports
---------------

TCMS can generate testing reports based on search conditions.

Procedure: Creating a testing report
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

To create a product report:

#. From the **REPORTING** tab, click **Testing Report**.

   |The Testing Report tab|

#. Select the product from the drop down box and either 1 or a range of
   versions.

   |Search details. 2|

#. Click **Generate Report**. The results are displayed.
 
.. note::

  No additional information is required to generate the testing report but
  if you want to provide values for Execute Date and Report Type you will
  get more specific results.

.. |The Reporting button 1| image:: ../_static/Navigation_Tabs.png
.. |The product selection screen.| image:: ../_static/Select_Product.png
.. |The product overview screen.| image:: ../_static/Product_Overview.png
.. |The product version screen.| image:: ../_static/Product_Versions.png
.. |The product build screen.| image:: ../_static/Product_Builds.png
.. |The Reporting button 2| image:: ../_static/Tab_Report_Custom.png
.. |Search details. 1| image:: ../_static/Report_Custom_Search.png
.. |Report Results.| image:: ../_static/Report_Custom_Results.png
.. |The Testing Report tab| image:: ../_static/Tab_Report_Testing.png
.. |Search details. 2| image:: ../_static/Testing_Report.png
